@@ -25,7 +25,7 @@ def _all_subclasses(cls):
 
 def _only_concrete_models(iterable):
     for model in iterable:
-        if not model._meta.abstract and model._meta.managed:
+        if not model._meta.abstract and not model._meta.proxy:
             yield model
 
 
@@ -133,7 +133,7 @@ def load_dump(data, *, progress=silence, ignorenonexistent=False):
 
             progress(f"Saved {len(objs)} {spec['model']} objects")
 
-        for spec in data["specs"]:
+        for spec in reversed(data["specs"]):
             if not spec.get("delete_missing"):
                 continue
 
